@@ -7,9 +7,9 @@
 "
 )]
 
-//! # 30 Seconds of Rust 🦀
+//! # Dryip of Rust 🦀
 //!
-//! Hello, and welcome to the 30 Seconds of Rust 🦀 website! 👋
+//! Hello, and welcome to the Dryip of Rust 🦀 website! 👋
 //!
 //! - Each function categorized into appropriate module.
 //! - Use the search bar to find the function.
@@ -17,6 +17,8 @@
 //!
 
 pub mod arrays;
+pub mod dates;
+pub mod error;
 pub mod maths;
 pub mod strings;
 
@@ -34,10 +36,19 @@ pub fn sorted(word: &str) -> String {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use proptest::prelude::*;
 
     #[test]
     fn test_sorted() {
         assert_eq!("aaagmnr", sorted("anagram"));
         assert_eq!("aceimn", sorted("iceman"));
     }
+
+    proptest! {
+        #[test]
+        fn strings(s in "\\PC*") {
+            println!("test input: {:?}", s);
+            sorted(&s);
+        }
+    }
 }
